// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"net/http"
	"smart-government-management-gateway/errors"
	param_v1 "smart-government-management-gateway/param/v1"
	"smart-government-management-gateway/pb"
	"smart-government-management-gateway/pb/v1"
	"smart-government-management-gateway/utils"

	"github.com/gin-gonic/gin"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/tasker/httptasker"
	"github.com/jaryhe/gopkgs/util"
	"go.uber.org/zap"
)


//
// @Summary 扬尘最近数据
// @Description 扬尘最近数据
// @Tags  扬尘监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param type query int false " "
// @Param sn query string false " "
// @Success 200 {object} v1.LatestDustMonitorDataResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/dust/last [get]
func (c *Controller) LatestDustMonitorData(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.LatestDustMonitorDataRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.LatestDustMonitorQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		resp := param_v1.LatestDustMonitorDataResponse{}
		rpcReq := &v1.LatestDustMonitorDataRequest{
			Sn:   req.Sn,
			Type: req.Type,
		}

		rpcRsp, err := pb.Government.LatestDustMonitorData(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Government.LatestDustMonitorData"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp.Data
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}


//
// @Summary 扬尘aqi
// @Description 扬尘aqi
// @Tags 扬尘监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param sn query string true " "
// @Success 200 {object} v1.DustAqiResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/dust/aqi [get]
func (c *Controller) DustAqi(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DustAqiRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.DustAqiQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		resp := param_v1.DustAqiResponse{}
		rpcReq := &v1.DustAqiRequest{
			Sn:req.Sn,
		}

		rpcRsp, err := pb.Government.DustAqi(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Government.DustAqi"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data.Aqi = int(rpcRsp.Aqi)
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}
