// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"fmt"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/tasker/httptasker"
	"github.com/jaryhe/gopkgs/util"
	"net/http"
	"smart-government-management-gateway/consts"
	"smart-government-management-gateway/errors"
	param_v1 "smart-government-management-gateway/param/v1"
	"smart-government-management-gateway/pb"
	"smart-government-management-gateway/pb/v1"
	"strconv"
	"strings"
	"github.com/gin-gonic/gin"
	"go.uber.org/zap"
	"smart-government-management-gateway/utils"
)

// 供应商列表
// @Summary 供应商列表
// @Description 供应商列表
// @Tags provider
// @Accept  json
// @Produce  json
// @Param token header string true "token"
// @Param page query int true "page"
// @Param filter query string false " "
// @Success 200 {object} v1.ProviderListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/provider/list [get]
func (c *Controller) ProviderList(ctx *gin.Context) {
	// 解析参数
	var loginUid int64
	var userName string
	req := &param_v1.ProviderListRequest{}
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.ProviderListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid,userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {

		// 响应数据
		resp := param_v1.ProviderListResponse{}
		rpcReq := &v1.ProviderListRequest{
			Page:req.Page,
			Filter:req.Filter,
		}
		req.FilterStatus = "1"
		if req.FilterStatus != "" {
			array := strings.Split(req.FilterStatus, ",")
			for _, v := range array {
				value, _ := strconv.Atoi(v)
				rpcReq.FilterStatus = append(rpcReq.FilterStatus, int32(value))
			}
		}
		if rpcReq.Page < 1 {
			rpcReq.Page = 1
		}

		rpcRsp, err := pb.Government.ProviderList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Government.ProviderList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return err
		}
		resp.Data = *rpcRsp
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.ProviderItem, 0)
		}

		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}


// 供应商申请列表
// @Summary 供应商申请列表
// @Description 供应商申请列表
// @Tags provider
// @Accept  json
// @Produce  json
// @Param token header string true "token"
// @Param page query int true "page"
// @Param filter query string false " "
// @Success 200 {object} v1.ProviderListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/provider/apply_list [get]
func (c *Controller) ProviderApplyList(ctx *gin.Context) {
	// 解析参数
	var loginUid int64
	var userName string
	req := &param_v1.ProviderListRequest{}
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.ProviderListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid,userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {

		// 响应数据
		resp := param_v1.ProviderListResponse{}
		rpcReq := &v1.ProviderListRequest{
			Page:req.Page,
			Filter:req.Filter,
		}
		req.FilterStatus = fmt.Sprintf("%d,%d", consts.StatusAuditedFail, consts.StatusAuditting)
		if req.FilterStatus != "" {
			array := strings.Split(req.FilterStatus, ",")
			for _, v := range array {
				value, _ := strconv.Atoi(v)
				rpcReq.FilterStatus = append(rpcReq.FilterStatus, int32(value))
			}
		}
		if rpcReq.Page < 1 {
			rpcReq.Page = 1
		}

		rpcRsp, err := pb.Government.ProviderList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Government.ProviderList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return err
		}
		resp.Data = *rpcRsp
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.ProviderItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}



