// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"github.com/gin-gonic/gin"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/tasker/httptasker"
	"github.com/jaryhe/gopkgs/util"
	"go.uber.org/zap"
	"net/http"
	"smart-government-management-gateway/errors"
	param_v1 "smart-government-management-gateway/param/v1"
	"smart-government-management-gateway/pb"
	"smart-government-management-gateway/pb/v1"
	"smart-government-management-gateway/utils"
)


//
// @Summary 员工类型出勤统计
// @Description 员工类型出勤统计
// @Tags staff
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Success 200 {object} v1.StaffStatisticNewResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/staff/type_statistic [get]
func (c *Controller) StaffStatisticNew(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.StaffStatisticNewRequest{}
	resp := param_v1.StaffStatisticNewResponse{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleStaffTypeTask := func() error {
		// 响应数据
		rpcReq := &v1.StaffTypeStatisticsRequest{

		}

		rpcRsp, err := pb.Government.StaffTypeStatistics(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Government.StaffTypeStatistics"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data.StaffTypeStatisticData = *rpcRsp
		if resp.Data.StaffTypeStatisticData.List == nil {
			resp.Data.StaffTypeStatisticData.List = []*v1.StaffTypeStatistics{}
		}
		return nil
	}

	handleWorkTypeTask := func() error {
		// 响应数据
		rpcReq := &v1.StaffWorkTypeStatisticsRequest{

		}

		rpcRsp, err := pb.Government.StaffWorkTypeStatistics(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Government.StaffWorkTypeStatistics"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data.WorkTypeStatisticData = *rpcRsp
		if resp.Data.WorkTypeStatisticData.List == nil {
			resp.Data.WorkTypeStatisticData.List = []*v1.WorkTypeStatistics{}
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleStaffTypeTask, handleWorkTypeTask)

}

